% Script "config.m"
% _______________________________________________________
% Configuration parameters for "PLC_channel_generator.p"
% or for "PLC_channel_generator_2.p" (cables with gamma distribution)

% Use notice:
% See the "User guide" document at www.plc.uma.es for more details
% __________________________________________________________


% GENERAL PARAMETERS
% __________________________________________________________
modo=0; % control flag, indicates {0,1}={manual,random} configuration

% Discretization parameters
% =========================
N=2048; % number of frequency points
f_min=0.1e6; % minimum frequency, higher than 0 Hz
f_max=30e6; % maximum frequency
M=50; % number (even) of discrete invariant states in a mains cycle

% impedance of transmitter and receiver
% =====================================
%load('ImpedGen_2.mat')
%Zg=Zg.';
%Zl=Zl.';
Zg=50; % transmitter
Zl=50; % receiver 
% __________________________________________________________

% =========================
f=[0:1/(N-1):1].'*(f_max-f_min)+f_min;   % calculation of frecuency index
X=7; % number of sections of transmission line
l=zeros(1,X);
t=zeros(1,X);
net=zeros(X,4); % matrix that contains the network structure
% =========================

% ONLY FOR MANUAL CONFIGURATION
% __________________________________________________________
if modo==0,
    
    % cables length and type definition
    % =================================
    % default channel:
    l=[0.8,32,13.8,37.6,46.8,50.1,37.2]; %  vector of line sections lengths (in metres)
    t=[5,5,2,2,5,2,4]; % vector of cable types
    % {1,2,3,4,5}= {1'5,2'5,4,6,10} section in mm²

    % loads definition
    % ================
    
    % only 3 impedances must be defined: Z1,Z2,Z3
    % They can be constants, vectors 1xN or matrices NxM
    
    % Definition of the frequency-selective impedances
    Z_1=impedance_f(f,863,6,2.7e6);   %RLC resonator
    Z_2=impedance_f(f,394,34,10.7e6);   %RLC resonator
    Z_3=impedance_f(f,1312,9,10.07e6);   %RLC resonator
    
    if tipo==0, % LTI case
        Z1=Z_1;
        Z2=Z_2;
        Z3=Z_3;
        
    else if tipo==1, % LPTV harmonic case
            phi=0; % initial phase of the impedance variation relative to the zero-crossing
            % of the mains cycle
            Z_a=repmat(50,N,1); % invariant part of the impedance
            Z1=Z_1;
            Z2=Z_2;
            Z3=impedance1_t(M,Z_a,Z_3,phi);
            
        else  % LPTV commuted case
            D=2; % D: initial delay of the first transition, relative to the zero-crossing
            %  of the mains cycle (D must be less than L/2-T)
            %Z_aa=repmat(1e6,N,1);  % off-state impedance
            T=20; % on-state duration in discrete time index (T must be less than M/2)
            Z1=Z_1;
            Z2=Z_2;
            Z3=impedance2_t(M,Z_3*0.5,Z_3,D,T);
        end
    end
    clear Z_1 Z_2 Z_3;
    
    % NOTE: The remaining parameters ONLY should be modified to change the cables structure
    % =====================================================================================
    
    % electrical cables data definition
    % =================================
    [R,L,C,G]=Datcables_altered(f);
    % R matrix Nx5 in ohm/m
    % L matrix Nx5 in H/m
    % C matrix Nx5 in F/m
    % G matrix Nx5 in siemens/m
    
    % network topology structure
    % ==========================
    net={0,l(1),t(1),0; ...
        1,l(2),t(2),Z1; ...
        0,l(3),t(3),0; ...
        1,l(4),t(4),Z2; ...
        0,l(5),t(5),0; ...
        1,l(6),t(6),Z3; ...
        0,l(7),t(7),0};
    % first col==0, logitudinal, first col==1, stub
end
% __________________________________________________________

